#!/bin/sh
#
# Common script for RFS/ROS and CUD.
#
# This file is part of clean-device.
#
# Copyright (C) 2011 Nokia Corporation. All rights reserved.
#
# Contact: Karoliina T. Salminen <karoliina.t.salminen@nokia.com>
# Authors: Gabriel Schulhof <gabriel.schulhof@nokia.com>
#          David Kedves <dkedves@blumsoft.eu>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# version 2 as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
# 02110-1301 USA

# These are the MCE calls for getting/setting offline(==flight)/normal mode
# turn off all radios:
# dbus-send --system --dest=com.nokia.mce --print-reply /com/nokia/mce/request com.nokia.mce.request.req_radio_states_change uint32:0 uint32:1
# turn on all radios:
# dbus-send --system --dest=com.nokia.mce --print-reply /com/nokia/mce/request com.nokia.mce.request.req_radio_states_change uint32:1 uint32:1
# They require the aegis mce::DeviceModeControl token

source /usr/share/clean-device/aegis-check.sh

SYSCONFDIR="/etc"
CUD_RUN_PARTS_DIR="osso-cud-scripts"
RFS_RUN_PARTS_DIR="osso-rfs-scripts"
DEFHOME="/home/user"

LOGFILE=/dev/null

do_prepare()
{
  # Place the device into offline mode, so there are no phone calls during the process
  dbus-send --system --dest=com.nokia.mce --print-reply /com/nokia/mce/request com.nokia.mce.request.req_radio_states_change uint32:0 uint32:1

  # Start the display on keeper script
  /usr/share/clean-device/keep-display-on.sh &

  # Give the user some time to notice that "we're dying"
  sleep 5
}

show_message() # $1 = logical ID for major message, $2 = logical ID for minor messages
{
  # 30 minutes (to make sure)
  TIMEOUT=1800000

  # Show the "we're dying" screen
  dbus-send --session --type=method_call --dest=com.nokia.systemui --print-reply / com.nokia.systemui.shutdownui.showScreen string:"$1" string:"$2" int32:${TIMEOUT}
}

run_dir() # $1 = directory wherein to run *.sh
{
  if test -d "$1"; then
    for the_script in $(ls "$1"/*.sh | grep -v cud-uninstall-packages); do
      echo "$(date) calling: $the_script ..." >> ${LOGFILE}
      $the_script >> ${LOGFILE}
      echo "$(date)    done: $the_script ." >> ${LOGFILE}
    done
  fi
}

epilogue() # $1 = cud | rfs
{
  # Show the "done" message
  if test "x$1" = "xrfs"; then
    show_message "qtn_rset_restore_down" "qtn_rset_restore_operator"
  elif test "x$1" = "xcud"; then
    show_message "qtn_rset_clear_down" "qtn_rset_restore_operator"
  fi

  # Kill the display on keeper ...
  touch /tmp/cud_finished

  # Leave system-ui some time to show the "done" msg.
  sleep 10

  # Try various reboot methods
  dbus-send --system --type=method_call --dest="com.nokia.dsme" --print-reply "/com/nokia/dsme/request" com.nokia.dsme.request.req_reboot || \
  shutdown -r now || reboot
}

do_data_wipe() # No parameters
{
  # Ask device lock to initate a data-wipe after the reboot and shut down when it finished.
  dbus-send --system --type=method_call --print-reply --dest=com.nokia.devicelock /request com.nokia.devicelock.dataWipe int32:0
}

# Few preliminary checks

if test "x${HOME}" = "x"; then
  HOME=${DEFHOME}
  echo "$0: Warning, HOME is not defined, assuming '${HOME}'"
fi

LOGPATH=/var/clean-device
if [ -f ${LOGPATH}/log ]; then
    LOGFILE=${LOGPATH}/clean-device.sh.log
    echo "$(date) ===== started $@ =====" >> ${LOGFILE}
fi
unset LOGPATH

# Assemble and run the different directories

if test "x$1" = "x--rfs"; then
  show_message "qtn_rset_restore_down" "qtn_rset_wait"
  do_prepare
  run_dir "${SYSCONFDIR}/${RFS_RUN_PARTS_DIR}"
  epilogue "rfs"

elif test "x$1" = "x--cud-reset"; then
  show_message "qtn_rset_clear_down" "qtn_rset_wait"
  do_prepare
  do_data_wipe

elif test "x$1" = "x--cud"; then
  show_message "qtn_rset_clear_down" "qtn_rset_wait"
  run_dir "${SYSCONFDIR}/${CUD_RUN_PARTS_DIR}"
  run_dir "${HOME}/.${CUD_RUN_PARTS_DIR}"
  show_message "qtn_rset_clear_down" "qtn_rset_wait"
  echo "$(date) uninstalling user apps ..." >> ${LOGFILE}
  ${SYSCONFDIR}/${CUD_RUN_PARTS_DIR}/cud-uninstall-packages.sh >> ${LOGFILE}
  echo "$(date) done." >> ${LOGFILE}
  epilogue "cud"

else
  echo 'Usage:' $(basename $0) 'option'
  echo 'option is one of the following:'
  echo '--rfs                   restore factory settings'
  echo '--cud                   clear user data'
  echo '--cud-reset             initiate clear user data process (set flag and reboot)'
  exit 1
fi

